@@ -1,4 +1,4 @@
-from .checksum import CacheAndCheck, checksum
-from .cache import CacheToDisk
 from .base import get_repo
-from .registry import register, gather_datasets
+from .cache import CacheToDisk
+from .checksum import CacheAndCheck, checksum
+from .registry import gather_datasets, register
